[PATCH] clang-format: [JS] Fix function formatting

Adam Strzelecki ono at java.pl
Wed Jun 18 05:05:44 PDT 2014


Added sample and proper SVN revision reference.

http://reviews.llvm.org/D4190

Files:
  lib/Format/UnwrappedLineParser.cpp
  lib/Format/UnwrappedLineParser.h

Index: lib/Format/UnwrappedLineParser.h
===================================================================
--- lib/Format/UnwrappedLineParser.h
+++ lib/Format/UnwrappedLineParser.h
@@ -101,7 +101,7 @@
   void parseObjCProtocol();
   bool tryToParseLambda();
   bool tryToParseLambdaIntroducer();
-  void tryToParseJSFunction();
+  void tryToParseJSFunction(bool BracedList = false);
   void addUnwrappedLine();
   bool eof() const;
   void nextToken();
-------------- next part --------------
A non-text attachment was scrubbed...
Name: D4190.10550.patch
Type: text/x-patch
Size: 1315 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/cfe-commits/attachments/20140618/0b7a89a7/attachment.bin>


More information about the cfe-commits mailing list
Index: lib/Format/UnwrappedLineParser.cpp
===================================================================
--- lib/Format/UnwrappedLineParser.cpp
+++ lib/Format/UnwrappedLineParser.cpp
@@ -905,11 +905,11 @@
   return false;
 }
 
-void UnwrappedLineParser::tryToParseJSFunction() {
+void UnwrappedLineParser::tryToParseJSFunction(bool BracedList) {
   nextToken();
 
-  // Consume function name.
-  if (FormatTok->is(tok::identifier))
+  // Consume function name if in braced list.
+  if (BracedList && FormatTok->is(tok::identifier))
       nextToken();
 
   if (FormatTok->isNot(tok::l_paren))
@@ -945,7 +945,7 @@
   do {
     if (Style.Language == FormatStyle::LK_JavaScript &&
         FormatTok->TokenText == "function") {
-      tryToParseJSFunction();
+      tryToParseJSFunction(true);
       continue;
     }
     switch (FormatTok->Tok.getKind()) {